@@ -21,7 +21,7 @@ NCBI/PubMed abstracts database.
 
 =head1 VERSION
 
-This document describes WWW::Search::PubMed version 1.004_01,
+This document describes WWW::Search::PubMed version 1.004_02,
 released 31 October 2007.
 
 =head1 REQUIRES
@@ -31,7 +31,7 @@ released 31 October 2007.
 
 =cut
 
-our($VERSION)	= '1.004_01';
+our($VERSION)	= '1.004_02';
 
 use strict;
 use warnings;
@@ -235,7 +235,16 @@ sub get_text_node {
 	my $self	= shift;
 	my $node	= shift;
 	my $name	= shift;
-	my $text	= eval { ($node->getElementsByTagName($name)->item(0)->getChildNodes)[0]->getNodeValue() };
+# 	my $text	= eval { ($node->getElementsByTagName($name)->item(0)->getChildNodes)[0]->getNodeValue() };
+# 	warn 'text node: ' . Dumper($text);
+# 	
+# 	use Data::Dumper;
+# 	if (defined($text) and $text =~ /of dynein partners dynactin p150/) {
+	my $text = eval {
+		my $element = $node->getElementsByTagName($name)->item(0);
+		my $elements = $element->getChildNodes;
+		my $t	= join('', map { $_->toString } @$elements);
+	};
 	if ($@) {
 		warn "XML[$name]: $@" if ($debug);
 		return undef;
